@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for ECLiPSe 6.1#143 and later versions
-%  Last updated on August 5, 2019
+%  Last updated on August 28, 2019
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
@@ -109,6 +109,8 @@
 
 % forall(+callable, +callable)
 
+:- meta_predicate(forall(0, 0)).
+
 forall(Generate, Test) :-
 	\+ (Generate, \+ Test).
 
@@ -361,6 +363,7 @@ forall(Generate, Test) :-
 '$lgt_default_flag'(singleton_variables, warning).
 '$lgt_default_flag'(steadfastness, silent).
 '$lgt_default_flag'(naming, silent).
+'$lgt_default_flag'(duplicated_clauses, silent).
 '$lgt_default_flag'(portability, silent).
 '$lgt_default_flag'(redefined_built_ins, silent).
 '$lgt_default_flag'(deprecated, warning).
@@ -601,13 +604,15 @@ forall(Generate, Test) :-
 
 :- if((get_flag(version_as_list, Version), Version @>= [7,0,35])).
 	'$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
-		get_stream_info(Stream, line, LineBegin),
+		get_stream_info(Stream, line, LineLast),
 		read_term(Stream, Term, [syntax_errors(error), variable_names(Variables)| Options]),
+		LineBegin is LineLast + 1,
 		get_stream_info(Stream, line, LineEnd).
 :- else.
 	'$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
-		get_stream_info(Stream, line, LineBegin),
+		get_stream_info(Stream, line, LineLast),
 		(	read_term(Stream, Term, [variable_names(Variables)| Options]) ->
+			LineBegin is LineLast + 1,
 			get_stream_info(Stream, line, LineEnd)
 		;	throw(syntax_error)
 		).
