@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for SICStus Prolog 4.1.0 and later versions
-%  Last updated on August 5, 2019
+%  Last updated on August 28, 2019
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
@@ -93,6 +93,8 @@
 
 % forall(+callable, +callable)
 
+:- meta_predicate(forall(0, 0)).
+
 forall(Generate, Test) :-
 	\+ (Generate, \+ Test).
 
@@ -293,6 +295,7 @@ forall(Generate, Test) :-
 '$lgt_default_flag'(singleton_variables, warning).
 '$lgt_default_flag'(steadfastness, silent).
 '$lgt_default_flag'(naming, silent).
+'$lgt_default_flag'(duplicated_clauses, silent).
 '$lgt_default_flag'(portability, silent).
 '$lgt_default_flag'(redefined_built_ins, silent).
 '$lgt_default_flag'(deprecated, warning).
@@ -512,7 +515,7 @@ forall(Generate, Test) :-
 % '$lgt_stream_current_line_number'(@stream, -integer)
 
 '$lgt_stream_current_line_number'(Stream, Line) :-
-	stream_property(Stream, position(Position)),
+	stream_position(Stream, Position),
 	stream_position_data(line_count, Position, LineCount),
 	Line is LineCount + 1.
 
@@ -813,6 +816,8 @@ forall(Generate, Test) :-
 
 % '$lgt_user_module_qualification'(@callable, -callable)
 
+:- dynamic('$lgt_user_module_qualification'/2).
+
 :- initialization((
 	prolog_load_context(module, Module),
 	assertz('$lgt_user_module_qualification'(Goal, Module:Goal))
